package meow

import (
	"time"

	"github.com/ProtonMail/gopenpgp/v2/crypto"
	"github.com/rs/zerolog/log"
)

type KeyPair struct {
	Public    string
	Private   string
	Generated time.Time
}

type KeysArray []KeyPair

func NewKeyPair() KeyPair {
	var kp KeyPair
	keys, err := crypto.GenerateKey("name", "mail", "rsa", 4096)
	if err != nil {
		log.Debug().Msg("Key generation failed")
	}
	kp.Generated = time.Now()
	kp.Public, err = keys.GetArmoredPublicKey()
	if err != nil {
		log.Debug().Msg("Public key extraction failed")
	}
	kp.Private, err = keys.Armor()
	if err != nil {
		log.Debug().Msg("Private key extraction failed")
	}
	return kp
}

func (keyPair *KeyPair) GetCryptoKeyObject() *crypto.Key {
	key, err := crypto.NewKeyFromArmored(keyPair.Private)
	if err != nil {
		log.Debug().Msg("Create key from armoured failed")
	}
	return key
}
